# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateApplicationAppVisibilityReqAddUsers(object):
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 与 user_id 至少给其中之一，user_id 优先于 open_id
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})


@attr.s
class UpdateApplicationAppVisibilityReqDelUsers(object):
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 与 user_id 至少给其中之一，user_id 优先于 open_id
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})


@attr.s
class UpdateApplicationAppVisibilityReq(object):
    app_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 目标应用的 ID
    del_users: UpdateApplicationAppVisibilityReqDelUsers = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 删除的用户列表，元素个数不超过 500，**先增加后删除**
    add_users: UpdateApplicationAppVisibilityReqAddUsers = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 增加的用户列表，元素个数不超过500，**先增加后删除**
    is_visiable_to_all: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 是否全员可见，0：否；1：是；不填：继续当前状态不改变
    add_departments: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 添加的部门列表，元素个数不超过 500，**先增加后删除**
    del_departments: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 删除的部门列表，元素个数不超过 500，**先增加后删除**


@attr.s
class UpdateApplicationAppVisibilityResp(object):
    pass


def _gen_update_application_app_visibility_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateApplicationAppVisibilityResp,
        scope="Application",
        api="UpdateApplicationAppVisibility",
        method="POST",
        url="https://open.feishu.cn/open-apis/application/v3/app/update_visibility",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMeetingRoomRoomListReq(object):
    building_id: str = attr.ib(default="", metadata={"req_type": "query"})  # 被查询的建筑物 ID
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 请求期望返回的会议室数量，不足则返回全部，该值默认为 100，最大为 1000
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于标记当前请求的分页标记，将返回以当前分页标记开始，往后 page_size 个元素
    order_by: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 提供用于对名称/楼层进行升序/降序排序的方式查询，可选项有："name-asc,name-desc,floor_name-asc,floor_name-desc"，传入其他字符串不做处理，默认无序
    fields: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用于指定返回的字段名，每个字段名之间用逗号 "," 分隔，如：“id,name”，"*" 表示返回全部字段，可选字段有："id,name,description,capacity,building_id,building_name,floor_name,is_disabled,display_id"，默认返回所有字段


@attr.s
class GetMeetingRoomRoomListRespRooms(object):
    room_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室 ID
    building_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室所属建筑物 ID
    building_name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 会议室所属建筑物名称
    capacity: int = attr.ib(default=0, metadata={"req_type": "json"})  # 会议室能容纳的人数
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室的相关描述
    display_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室的展示 ID
    floor_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室所在楼层名称
    is_disabled: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 会议室是否不可用，若会议室不可用，则该值为 true，否则为 false
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室名称


@attr.s
class GetMeetingRoomRoomListResp(object):
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，存在下一页时返回
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 存在下一页时，该值为 true，否则为 false
    rooms: GetMeetingRoomRoomListRespRooms = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 会议室列表


def _gen_get_meeting_room_room_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMeetingRoomRoomListResp,
        scope="MeetingRoom",
        api="GetMeetingRoomRoomList",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/room/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveDocRawContentReq(object):
    doc_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 获取方式详见 [准备接入文档 API](https://open.feishu.cn/document/ukTMukTMukTM/ugzNzUjL4czM14CO3MTN/guide/getting-start)


@attr.s
class GetDriveDocRawContentResp(object):
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 如: string


def _gen_get_drive_doc_raw_content_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveDocRawContentResp,
        scope="Drive",
        api="GetDriveDocRawContent",
        method="GET",
        url="https://open.feishu.cn/open-apis/doc/v2/:docToken/raw_content",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteHelpdeskFAQReq(object):
    id: str = attr.ib(default="", metadata={"req_type": "path"})  # id, 示例值："12345"


@attr.s
class DeleteHelpdeskFAQResp(object):
    pass


def _gen_delete_helpdesk_faq_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteHelpdeskFAQResp,
        scope="Helpdesk",
        api="DeleteHelpdeskFAQ",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/faqs/:id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDrivePublicPermissionV2Req(object):
    token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件的 token，获取方式见 [对接前说明](https://open.feishu.cn/document/ukTMukTMukTM/uczNzUjL3czM14yN3MTN)的第 4 项
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文档类型 "doc", "sheet" or "isv"


@attr.s
class GetDrivePublicPermissionV2Resp(object):
    security_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 可创建副本/打印/导出/复制设置：<br>"anyone_can_view" - 所有可访问此文档的用户<br>"anyone_can_edit" - 有编辑权限的用户
    comment_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 可评论设置：<br>"anyone_can_view" - 所有可访问此文档的用户<br>"anyone_can_edit" - 有编辑权限的用户
    share_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 谁可以添加和管理协作者：<br>"anyone"-所有可阅读或编辑此文档的用户<br>"same_tenant"-组织内所有可阅读或编辑此文档的用户<br>"only_me"-只有我可以
    link_share_entity: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 链接共享：<br>"tenant_readable" - 组织内获得链接的人可阅读<br>"tenant_editable" - 组织内获得链接的人可编辑<br>"anyone_readable" - 获得链接的任何人可阅读<br>"anyone_editable" - 获得链接的任何人可编辑
    external_access: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否允许分享到租户外开关
    invite_external: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 非owner是否允许邀请外部人
    permission_version: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 权限版本号


def _gen_get_drive_public_permission_v2_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDrivePublicPermissionV2Resp,
        scope="Drive",
        api="GetDrivePublicPermissionV2",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/permission/v2/public/",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateApprovalInstanceReqNodeApproverOpenIDList(object):
    pass


@attr.s
class CreateApprovalInstanceReqNodeApproverUserIDList(object):
    pass


@attr.s
class CreateApprovalInstanceReqForm(object):
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 控件 ID，也可以使用自定义 ID custom_id 的值
    type: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件类型
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # 控件值，不同类型的值格式不一样


@attr.s
class CreateApprovalInstanceReq(object):
    approval_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批定义 code
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 发起审批用户
    tenant_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 平台租户ID
    open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 发起审批用户 open id, 如果传了 user_id 则优先使用 user_id
    department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 发起审批用户部门，如果用户只属于一个部门，可以不填，如果属于多个部门，必须填其中一个部门
    form: CreateApprovalInstanceReqForm = attr.ib(
        factory=lambda: CreateApprovalInstanceReqForm(), metadata={"req_type": "json"}
    )  # json 数组，**控件值**
    node_approver_user_id_list: CreateApprovalInstanceReqNodeApproverUserIDList = attr.ib(
        factory=lambda: CreateApprovalInstanceReqNodeApproverUserIDList(),
        metadata={"req_type": "json"},
    )  # 如果有发起人自选节点，则需要填写对应节点的审批人<br>key:  node id 或 custom node id , 通过 [查看审批定义](https://open.feishu.cn/document/ukTMukTMukTM/uADNyUjLwQjM14CM0ITN) 获取<br> value: 审批人列表
    node_approver_open_id_list: CreateApprovalInstanceReqNodeApproverOpenIDList = (
        attr.ib(
            factory=lambda: CreateApprovalInstanceReqNodeApproverOpenIDList(),
            metadata={"req_type": "json"},
        )
    )  # 发起人自选 open id
    uuid: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 审批实例 uuid，用于幂等操作，同一个 uuid 只能用于创建一个审批实例，如果冲突，返回错误码 60012 ，格式必须为 XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX，不区分大小写


@attr.s
class CreateApprovalInstanceResp(object):
    instance_code: str = attr.ib(default="", metadata={"req_type": "json"})  # 审批实例 Code


def _gen_create_approval_instance_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateApprovalInstanceResp,
        scope="Approval",
        api="CreateApprovalInstance",
        method="POST",
        url="https://www.feishu.cn/approval/openapi/v2/instance/create",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceStatisticsDataReqEmployeeType(object):
    pass


@attr.s
class GetAttendanceStatisticsDataReq(object):
    employee_type: GetAttendanceStatisticsDataReqEmployeeType = attr.ib(
        factory=lambda: GetAttendanceStatisticsDataReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 用户 ID 类型, 可选值有: `employee_id`, `employee_no`
    locale: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 语言类型, 可选值有: `en`：英文, `ja`：日文, `zh`：中文
    stats_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 统计类型,      , 可选值有: `daily`：日度统计, `month`：月度统计
    start_date: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 开始时间, 示例值：20210316
    end_date: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 结束时间, 示例值：20210323,      ,      （时间间隔不超过 40 天）
    user_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 查询的用户 ID 列表,      ,      （用户数量不超过 20）
    need_history: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否包含历史数据, 示例值：true
    current_group_only: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否只包含当前考勤组, 示例值：true


@attr.s
class GetAttendanceStatisticsDataRespUserDataDataFeature(object):
    key: str = attr.ib(default="", metadata={"req_type": "json"})  # 属性名
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # 属性值


@attr.s
class GetAttendanceStatisticsDataRespUserDataData(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 字段编号
    value: str = attr.ib(default="", metadata={"req_type": "json"})  # 数据值
    features: typing.List[GetAttendanceStatisticsDataRespUserDataDataFeature] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 数据属性


@attr.s
class GetAttendanceStatisticsDataRespUserData(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 姓名
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    datas: typing.List[GetAttendanceStatisticsDataRespUserDataData] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 数据


@attr.s
class GetAttendanceStatisticsDataResp(object):
    user_datas: typing.List[GetAttendanceStatisticsDataRespUserData] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户统计数据


def _gen_get_attendance_statistics_data_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceStatisticsDataResp,
        scope="Attendance",
        api="GetAttendanceStatisticsData",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_stats_datas/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAdminUserStatsReqDepartmentIDType(object):
    pass


@attr.s
class GetAdminUserStatsReqUserIDType(object):
    pass


@attr.s
class GetAdminUserStatsReq(object):
    user_id_type: GetAdminUserStatsReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    department_id_type: GetAdminUserStatsReqDepartmentIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 部门ID类型, 示例值："open_department_id", 可选值有: `department_id`：部门的 ID, `open_department_id`：部门的 Open ID
    start_date: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 起始日期（包含），格式是YYYY-mm-dd, 示例值："2020-02-15"
    end_date: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 终止日期（包含），格式是YYYY-mm-dd。起止日期之间相差不能超过31天（包含31天）, 示例值："2020-02-15"
    department_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 部门的 ID，取决于department_id_type, 示例值："od-382e2793cfc9471f892e8a672987654c"
    user_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户的open_id，user_id或者union_id，取决于user_id_type, 示例值："ou_7dab8a3d3cdcc9da365777c7ad535d62"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小，默认是10, 示例值：10, 取值范围：`1` ～ `20`
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；当返回的has_more为true时，会返回新的page_token，再次调用接口，传入这个page_token，将获得下一页数据, 示例值："2"


@attr.s
class GetAdminUserStatsRespItem(object):
    date: str = attr.ib(default="", metadata={"req_type": "json"})  # 日期
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    user_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    department_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门名
    department_path: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门路径
    create_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 添加时间
    user_active_flag: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户激活状态, 可选值有: `0`：未激活, `1`：已激活
    register_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 激活时间
    suite_active_flag: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户活跃状态, 可选值有: `0`：无活跃, `1`：活跃
    last_active_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 最近活跃时间
    im_active_flag: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户消息活跃状态, 可选值有: `0`：无活跃, `1`：活跃
    send_messenger_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 发送消息数
    docs_active_flag: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户云文档活跃状态, 可选值有: `0`：无活跃, `1`：活跃
    create_docs_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建文件数
    cal_active_flag: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户日历活跃状态, 可选值有: `0`：无活跃, `1`：活跃
    create_cal_num: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建日程数
    vc_active_flag: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户音视频会议活跃状态, 可选值有: `0`：无活跃, `1`：活跃
    vc_duration: int = attr.ib(default=0, metadata={"req_type": "json"})  # 会议时长
    active_os: str = attr.ib(default="", metadata={"req_type": "json"})  # 活跃设备


@attr.s
class GetAdminUserStatsResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否有下一页数据
    page_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 下一页分页的token
    items: typing.List[GetAdminUserStatsRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 数据报表


def _gen_get_admin_user_stats_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAdminUserStatsResp,
        scope="Admin",
        api="GetAdminUserStats",
        method="GET",
        url="https://open.feishu.cn/open-apis/admin/v1/admin_user_stats",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteCalendarACLReq(object):
    calendar_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 日历ID, 示例值："feishu.cn_xxxxxxxxxx@group.calendar.feishu.cn"
    acl_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # acl资源ID, 示例值："user_xxxxxx"


@attr.s
class DeleteCalendarACLResp(object):
    pass


def _gen_delete_calendar_acl_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteCalendarACLResp,
        scope="Calendar",
        api="DeleteCalendarACL",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/calendar/v4/calendars/:calendar_id/acls/:acl_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchSetSheetStyleReqDataStyleFont(object):
    bold: bool = attr.ib(default=None, metadata={"req_type": "json"})  # 是否加粗
    italic: bool = attr.ib(default=None, metadata={"req_type": "json"})  # 是否斜体
    font_size: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 字体大小 字号大小为9~36 行距固定为1.5，如:10pt/1.5


@attr.s
class BatchSetSheetStyleReqDataStyle(object):
    font: BatchSetSheetStyleReqDataStyleFont = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 字体相关样式
    text_decoration: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文本装饰 ，0 默认，1 下划线，2 删除线 ，3 下划线和删除线
    formatter: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 数字格式，详见附录 [sheet支持数字格式类型](https://open.feishu.cn/document/ukTMukTMukTM/uMjM2UjLzIjN14yMyYTN)
    h_align: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 水平对齐，0 左对齐，1 中对齐，2 右对齐
    v_align: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 垂直对齐, 0 上对齐，1 中对齐, 2 下对齐
    fore_color: str = attr.ib(default="", metadata={"req_type": "json"})  # 字体颜色
    back_color: str = attr.ib(default="", metadata={"req_type": "json"})  # 背景颜色
    border_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 边框类型，可选 "FULL_BORDER"，"OUTER_BORDER"，"INNER_BORDER"，"NO_BORDER"，"LEFT_BORDER"，"RIGHT_BORDER"，"TOP_BORDER"，"BOTTOM_BORDER"
    border_color: str = attr.ib(default="", metadata={"req_type": "json"})  # 边框颜色
    clean: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否清除所有格式,默认 false


@attr.s
class BatchSetSheetStyleReqData(object):
    ranges: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 查询范围，包含 sheetId 与单元格范围两部分，目前支持四种索引方式，详见 [在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    style: BatchSetSheetStyleReqDataStyle = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 需要更新的样式


@attr.s
class BatchSetSheetStyleReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    data: BatchSetSheetStyleReqData = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 请求数据


@attr.s
class BatchSetSheetStyleRespResponse(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的 token
    updated_range: str = attr.ib(default="", metadata={"req_type": "json"})  # 设置样式的范围
    updated_rows: int = attr.ib(default=0, metadata={"req_type": "json"})  # 设置样式的行数
    updated_columns: int = attr.ib(default=0, metadata={"req_type": "json"})  # 设置样式的列数
    updated_cells: int = attr.ib(default=0, metadata={"req_type": "json"})  # 设置样式的单元格数


@attr.s
class BatchSetSheetStyleResp(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # spreadsheet 的 token
    total_updated_rows: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 设置样式的总行数
    total_updated_columns: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 设置样式的总列数
    total_updated_cells: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 设置样式的单元格总数
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # sheet 的版本号
    responses: BatchSetSheetStyleRespResponse = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 各个范围的设置单元格样式的范围、行列数等


def _gen_batch_set_sheet_style_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchSetSheetStyleResp,
        scope="Drive",
        api="BatchSetSheetStyle",
        method="PUT",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/styles_batch_update",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetSearchDataSourceListReq(object):
    view: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 回包数据格式，0-全量数据；1-摘要数据。,**注**：摘要数据仅包含"id"，"name"，"state"。, 示例值：0, 可选值有: `0`：全量数据, `1`：摘要数据
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："PxZFma9OIRhdBlT/dOYNiu2Ro8F2WAhcby7OhOijfljZ"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`50`


@attr.s
class GetSearchDataSourceListRespItem(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 数据源的唯一标识
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # data_source的展示名称
    state: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 数据源状态，0-未上线，1-已上线, 可选值有: `0`：未上线, `1`：已上线
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 对于数据源的描述
    create_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 创建时间，使用Unix时间戳，单位为“秒”
    update_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 更新时间，使用Unix时间戳，单位为“秒”
    is_exceed_quota: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否超限


@attr.s
class GetSearchDataSourceListResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    items: typing.List[GetSearchDataSourceListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 数据源中的数据记录


def _gen_get_search_data_source_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetSearchDataSourceListResp,
        scope="Search",
        api="GetSearchDataSourceList",
        method="GET",
        url="https://open.feishu.cn/open-apis/search/v2/data_sources",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CheckUserIsInApplicationPaidScopeReq(object):
    open_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户 open_id，open_id 和 user_id 两个参数必须包含其一，若同时传入取 open_id
    user_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 用户 user_id，user_id 和 open_id 两个参数必须包含其一，若同时传入取 open_id


@attr.s
class CheckUserIsInApplicationPaidScopeResp(object):
    status: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户是否在开通范围中，"valid" -该用户在开通范围中，"not_in_scope"-该用户不在开通范围中，"no_active_license"-企业未购买任何价格方案或价格方案已过期，"exceeds_maximum_limit"-企业当前配置的付费功能开通范围人数超出限制，需提醒管理员调整
    price_plan_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户当前使用的「价格方案ID」，对应开发者后台中「价格方案配置」中的「价格方案」
    is_trial: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否为试用版本，true-是试用版本；false-非试用版本
    service_stop_time: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户当前有生效价格方案时表示价格方案的到期时间，为时间unix时间戳


def _gen_check_user_is_in_application_paid_scope_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CheckUserIsInApplicationPaidScopeResp,
        scope="Application",
        api="CheckUserIsInApplicationPaidScope",
        method="GET",
        url="https://open.feishu.cn/open-apis/pay/v1/paid_scope/check_user",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class TranslateTextReqGlossary(object):
    from_: str = attr.ib(default="", metadata={"req_type": "json"})  # 原文, 示例值："飞书"
    to: str = attr.ib(default="", metadata={"req_type": "json"})  # 译文, 示例值："Lark"


@attr.s
class TranslateTextReq(object):
    source_language: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 源语言, 示例值："zh"
    text: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 源文本, 示例值："尝试使用一下飞书吧"
    target_language: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 目标语言, 示例值："en"
    glossary: TranslateTextReqGlossary = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 请求级术语表，携带术语，仅在本次翻译中生效（最多能携带 128个术语词）


@attr.s
class TranslateTextResp(object):
    text: str = attr.ib(default="", metadata={"req_type": "json"})  # 翻译后的文本


def _gen_translate_text_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=TranslateTextResp,
        scope="AI",
        api="TranslateText",
        method="POST",
        url="https://open.feishu.cn/open-apis/translation/v1/text/translate",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationAppAdminUserListReq(object):
    pass


@attr.s
class GetApplicationAppAdminUserListRespUserOpenID(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 某管理员的user_id
    union_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 某管理员的union_id


@attr.s
class GetApplicationAppAdminUserListRespUser(object):
    open_id: GetApplicationAppAdminUserListRespUserOpenID = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 某管理员的open_id


@attr.s
class GetApplicationAppAdminUserListResp(object):
    user_list: typing.List[GetApplicationAppAdminUserListRespUser] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 管理员列表


def _gen_get_application_app_admin_user_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationAppAdminUserListResp,
        scope="Application",
        api="GetApplicationAppAdminUserList",
        method="GET",
        url="https://open.feishu.cn/open-apis/user/v4/app_admin_user/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDepartmentListReqDepartmentIDType(object):
    pass


@attr.s
class GetDepartmentListReqUserIDType(object):
    pass


@attr.s
class GetDepartmentListReq(object):
    user_id_type: GetDepartmentListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`,, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    department_id_type: GetDepartmentListReqDepartmentIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 此次调用中使用的部门ID的类型, 示例值："open_department_id", 可选值有: `department_id`：以自定义department_id来标识部门, `open_department_id`：以open_department_id来标识部门, 默认值: `open_department_id`
    parent_department_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 父部门的ID，填上获取部门下所有子部门, 示例值："od-4e6ac4d14bcd5071a37a39de902c7141"
    fetch_child: bool = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 是否递归获取子部门, 示例值：是否递归获取子部门，默认值：false
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："AQD9/Rn9eij9Pm39ED40/RD/cIFmu77WxpxPB/2oHfQLZ%2BG8JG6tK7%2BZnHiT7COhD2hMSICh/eBl7cpzU6JEC3J7COKNe4jrQ8ExwBCR"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`50`


@attr.s
class GetDepartmentListRespItemStatus(object):
    is_deleted: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否被删除


@attr.s
class GetDepartmentListRespItemI18nName(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门的中文名
    ja_jp: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门的日文名
    en_us: str = attr.ib(default="", metadata={"req_type": "json"})  # 部门的英文名


@attr.s
class GetDepartmentListRespItem(object):
    name: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 部门名称, 最小长度：`1` 字符,**字段权限要求（满足任一）**：, 获取部门基础信息, 以应用身份访问通讯录
    i18n_name: GetDepartmentListRespItemI18nName = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 国际化的部门名称,**字段权限要求（满足任一）**：, 获取部门基础信息, 以应用身份访问通讯录
    parent_department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 父部门的ID,* 创建根部门，该参数值为 “0”,**字段权限要求（满足任一）**：, 获取部门组织架构信息, 以应用身份访问通讯录
    department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 本部门的自定义部门ID, 最大长度：`128` 字符, 正则校验：`^0|[^od][A-Za-z0-9]*`,**字段权限要求（满足任一）**：, 获取部门基础信息, 以应用身份访问通讯录
    open_department_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 部门的open_id
    leader_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 部门主管用户ID,**字段权限要求（满足任一）**：, 获取部门组织架构信息, 以应用身份访问通讯录
    chat_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 部门群ID,**字段权限要求（满足任一）**：, 获取部门基础信息, 以应用身份访问通讯录
    order: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 部门的排序，即部门在其同级部门的展示顺序,**字段权限要求（满足任一）**：, 获取部门组织架构信息, 以应用身份访问通讯录
    unit_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 部门单位自定义ID列表，当前只支持一个,**字段权限要求（满足任一）**：, 获取部门组织架构信息, 以应用身份访问通讯录
    member_count: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 部门下用户的个数,**字段权限要求（满足任一）**：, 获取部门组织架构信息, 以应用身份访问通讯录
    status: GetDepartmentListRespItemStatus = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 部门状态,**字段权限要求（满足任一）**：, 获取部门基础信息, 以应用身份访问通讯录


@attr.s
class GetDepartmentListResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    items: typing.List[GetDepartmentListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )


def _gen_get_department_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDepartmentListResp,
        scope="Contact",
        api="GetDepartmentList",
        method="GET",
        url="https://open.feishu.cn/open-apis/contact/v3/departments",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_calendar_acl_create import (
    CreateCalendarACLReq,
    CreateCalendarACLResp,
    _gen_create_calendar_acl_req,
)
from pylark.api_service_calendar_acl_delete import (
    DeleteCalendarACLReq,
    DeleteCalendarACLResp,
    _gen_delete_calendar_acl_req,
)
from pylark.api_service_calendar_acl_get_list import (
    GetCalendarACLListReq,
    GetCalendarACLListResp,
    _gen_get_calendar_acl_list_req,
)
from pylark.api_service_calendar_acl_subscribe import (
    SubscribeCalendarACLReq,
    SubscribeCalendarACLResp,
    _gen_subscribe_calendar_acl_req,
)
from pylark.api_service_calendar_calendar_create import (
    CreateCalendarReq,
    CreateCalendarResp,
    _gen_create_calendar_req,
)
from pylark.api_service_calendar_calendar_delete import (
    DeleteCalendarReq,
    DeleteCalendarResp,
    _gen_delete_calendar_req,
)
from pylark.api_service_calendar_calendar_get import (
    GetCalendarReq,
    GetCalendarResp,
    _gen_get_calendar_req,
)
from pylark.api_service_calendar_calendar_get_list import (
    GetCalendarListReq,
    GetCalendarListResp,
    _gen_get_calendar_list_req,
)
from pylark.api_service_calendar_calendar_patch import (
    UpdateCalendarReq,
    UpdateCalendarResp,
    _gen_update_calendar_req,
)
from pylark.api_service_calendar_calendar_search import (
    SearchCalendarReq,
    SearchCalendarResp,
    _gen_search_calendar_req,
)
from pylark.api_service_calendar_calendar_subscribe import (
    SubscribeCalendarReq,
    SubscribeCalendarResp,
    _gen_subscribe_calendar_req,
)
from pylark.api_service_calendar_calendar_unsubscribe import (
    UnsubscribeCalendarReq,
    UnsubscribeCalendarResp,
    _gen_unsubscribe_calendar_req,
)
from pylark.api_service_calendar_calendar_subscription import (
    SubscribeCalendarChangeEventReq,
    SubscribeCalendarChangeEventResp,
    _gen_subscribe_calendar_change_event_req,
)
from pylark.api_service_calendar_calendar_event_create import (
    CreateCalendarEventReq,
    CreateCalendarEventResp,
    _gen_create_calendar_event_req,
)
from pylark.api_service_calendar_calendar_event_delete import (
    DeleteCalendarEventReq,
    DeleteCalendarEventResp,
    _gen_delete_calendar_event_req,
)
from pylark.api_service_calendar_calendar_event_get import (
    GetCalendarEventReq,
    GetCalendarEventResp,
    _gen_get_calendar_event_req,
)
from pylark.api_service_calendar_calendar_event_get_list import (
    GetCalendarEventListReq,
    GetCalendarEventListResp,
    _gen_get_calendar_event_list_req,
)
from pylark.api_service_calendar_calendar_event_patch import (
    UpdateCalendarEventReq,
    UpdateCalendarEventResp,
    _gen_update_calendar_event_req,
)
from pylark.api_service_calendar_calendar_event_search import (
    SearchCalendarEventReq,
    SearchCalendarEventResp,
    _gen_search_calendar_event_req,
)
from pylark.api_service_calendar_calendar_event_subscribe import (
    SubscribeCalendarEventReq,
    SubscribeCalendarEventResp,
    _gen_subscribe_calendar_event_req,
)
from pylark.api_service_calendar_calendar_event_attendee_create import (
    CreateCalendarEventAttendeeReq,
    CreateCalendarEventAttendeeResp,
    _gen_create_calendar_event_attendee_req,
)
from pylark.api_service_calendar_calendar_event_attendee_get_list import (
    GetCalendarEventAttendeeListReq,
    GetCalendarEventAttendeeListResp,
    _gen_get_calendar_event_attendee_list_req,
)
from pylark.api_service_calendar_calendar_event_attendee_delete import (
    DeleteCalendarEventAttendeeReq,
    DeleteCalendarEventAttendeeResp,
    _gen_delete_calendar_event_attendee_req,
)
from pylark.api_service_calendar_calendar_event_attendee_chat_member_list import (
    GetCalendarEventAttendeeChatMemberListReq,
    GetCalendarEventAttendeeChatMemberListResp,
    _gen_get_calendar_event_attendee_chat_member_list_req,
)
from pylark.api_service_calendar_calendar_freebusy_get_list import (
    GetCalendarFreeBusyListReq,
    GetCalendarFreeBusyListResp,
    _gen_get_calendar_free_busy_list_req,
)
from pylark.api_service_calendar_calendar_timeoff_event_create import (
    CreateCalendarTimeoffEventReq,
    CreateCalendarTimeoffEventResp,
    _gen_create_calendar_timeoff_event_req,
)
from pylark.api_service_calendar_calendar_timeoff_event_delete import (
    DeleteCalendarTimeoffEventReq,
    DeleteCalendarTimeoffEventResp,
    _gen_delete_calendar_timeoff_event_req,
)
from pylark.api_service_calendar_generate_caldav_conf import (
    GenerateCaldavConfReq,
    GenerateCaldavConfResp,
    _gen_generate_caldav_conf_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkCalendarService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def create_calendar_acl(
        self, request: CreateCalendarACLReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateCalendarACLResp, Response]:
        return self.cli.raw_request(_gen_create_calendar_acl_req(request, options))

    def delete_calendar_acl(
        self, request: DeleteCalendarACLReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteCalendarACLResp, Response]:
        return self.cli.raw_request(_gen_delete_calendar_acl_req(request, options))

    def get_calendar_acl_list(
        self, request: GetCalendarACLListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetCalendarACLListResp, Response]:
        return self.cli.raw_request(_gen_get_calendar_acl_list_req(request, options))

    def subscribe_calendar_acl(
        self, request: SubscribeCalendarACLReq, options: typing.List[str] = None
    ) -> typing.Tuple[SubscribeCalendarACLResp, Response]:
        return self.cli.raw_request(_gen_subscribe_calendar_acl_req(request, options))

    def create_calendar(
        self, request: CreateCalendarReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateCalendarResp, Response]:
        return self.cli.raw_request(_gen_create_calendar_req(request, options))

    def delete_calendar(
        self, request: DeleteCalendarReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteCalendarResp, Response]:
        return self.cli.raw_request(_gen_delete_calendar_req(request, options))

    def get_calendar(
        self, request: GetCalendarReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetCalendarResp, Response]:
        return self.cli.raw_request(_gen_get_calendar_req(request, options))

    def get_calendar_list(
        self, request: GetCalendarListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetCalendarListResp, Response]:
        return self.cli.raw_request(_gen_get_calendar_list_req(request, options))

    def update_calendar(
        self, request: UpdateCalendarReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateCalendarResp, Response]:
        return self.cli.raw_request(_gen_update_calendar_req(request, options))

    def search_calendar(
        self, request: SearchCalendarReq, options: typing.List[str] = None
    ) -> typing.Tuple[SearchCalendarResp, Response]:
        return self.cli.raw_request(_gen_search_calendar_req(request, options))

    def subscribe_calendar(
        self, request: SubscribeCalendarReq, options: typing.List[str] = None
    ) -> typing.Tuple[SubscribeCalendarResp, Response]:
        return self.cli.raw_request(_gen_subscribe_calendar_req(request, options))

    def unsubscribe_calendar(
        self, request: UnsubscribeCalendarReq, options: typing.List[str] = None
    ) -> typing.Tuple[UnsubscribeCalendarResp, Response]:
        return self.cli.raw_request(_gen_unsubscribe_calendar_req(request, options))

    def subscribe_calendar_change_event(
        self, request: SubscribeCalendarChangeEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[SubscribeCalendarChangeEventResp, Response]:
        return self.cli.raw_request(
            _gen_subscribe_calendar_change_event_req(request, options)
        )

    def create_calendar_event(
        self, request: CreateCalendarEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateCalendarEventResp, Response]:
        return self.cli.raw_request(_gen_create_calendar_event_req(request, options))

    def delete_calendar_event(
        self, request: DeleteCalendarEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteCalendarEventResp, Response]:
        return self.cli.raw_request(_gen_delete_calendar_event_req(request, options))

    def get_calendar_event(
        self, request: GetCalendarEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetCalendarEventResp, Response]:
        return self.cli.raw_request(_gen_get_calendar_event_req(request, options))

    def get_calendar_event_list(
        self, request: GetCalendarEventListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetCalendarEventListResp, Response]:
        return self.cli.raw_request(_gen_get_calendar_event_list_req(request, options))

    def update_calendar_event(
        self, request: UpdateCalendarEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateCalendarEventResp, Response]:
        return self.cli.raw_request(_gen_update_calendar_event_req(request, options))

    def search_calendar_event(
        self, request: SearchCalendarEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[SearchCalendarEventResp, Response]:
        return self.cli.raw_request(_gen_search_calendar_event_req(request, options))

    def subscribe_calendar_event(
        self, request: SubscribeCalendarEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[SubscribeCalendarEventResp, Response]:
        return self.cli.raw_request(_gen_subscribe_calendar_event_req(request, options))

    def create_calendar_event_attendee(
        self, request: CreateCalendarEventAttendeeReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateCalendarEventAttendeeResp, Response]:
        return self.cli.raw_request(
            _gen_create_calendar_event_attendee_req(request, options)
        )

    def get_calendar_event_attendee_list(
        self, request: GetCalendarEventAttendeeListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetCalendarEventAttendeeListResp, Response]:
        return self.cli.raw_request(
            _gen_get_calendar_event_attendee_list_req(request, options)
        )

    def delete_calendar_event_attendee(
        self, request: DeleteCalendarEventAttendeeReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteCalendarEventAttendeeResp, Response]:
        return self.cli.raw_request(
            _gen_delete_calendar_event_attendee_req(request, options)
        )

    def get_calendar_event_attendee_chat_member_list(
        self,
        request: GetCalendarEventAttendeeChatMemberListReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetCalendarEventAttendeeChatMemberListResp, Response]:
        return self.cli.raw_request(
            _gen_get_calendar_event_attendee_chat_member_list_req(request, options)
        )

    def get_calendar_free_busy_list(
        self, request: GetCalendarFreeBusyListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetCalendarFreeBusyListResp, Response]:
        return self.cli.raw_request(
            _gen_get_calendar_free_busy_list_req(request, options)
        )

    def create_calendar_timeoff_event(
        self, request: CreateCalendarTimeoffEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateCalendarTimeoffEventResp, Response]:
        return self.cli.raw_request(
            _gen_create_calendar_timeoff_event_req(request, options)
        )

    def delete_calendar_timeoff_event(
        self, request: DeleteCalendarTimeoffEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteCalendarTimeoffEventResp, Response]:
        return self.cli.raw_request(
            _gen_delete_calendar_timeoff_event_req(request, options)
        )

    def generate_caldav_conf(
        self, request: GenerateCaldavConfReq, options: typing.List[str] = None
    ) -> typing.Tuple[GenerateCaldavConfResp, Response]:
        return self.cli.raw_request(_gen_generate_caldav_conf_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMeetingRoomDistrictListReq(object):
    country_id: int = attr.ib(default=0, metadata={"req_type": "query"})  # 国家地区ID


@attr.s
class GetMeetingRoomDistrictListRespDistricts(object):
    district_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 城市ID
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 城市名称


@attr.s
class GetMeetingRoomDistrictListResp(object):
    districts: GetMeetingRoomDistrictListRespDistricts = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 城市列表


def _gen_get_meeting_room_district_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMeetingRoomDistrictListResp,
        scope="MeetingRoom",
        api="GetMeetingRoomDistrictList",
        method="GET",
        url="https://open.feishu.cn/open-apis/meeting_room/district/list",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CheckDriveMemberPermissionReq(object):
    token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文件的 token，获取方式见 [对接前说明](https://open.feishu.cn/document/ukTMukTMukTM/uczNzUjL3czM14yN3MTN)的第 4 项
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 文档类型  "doc"  or  "sheet" or "file"
    perm: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 权限，"view" or "edit" or "share"


@attr.s
class CheckDriveMemberPermissionResp(object):
    is_permitted: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否具有指定权限


def _gen_check_drive_member_permission_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CheckDriveMemberPermissionResp,
        scope="Drive",
        api="CheckDriveMemberPermission",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/permission/member/permitted",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteEmployeeTypeEnumReq(object):
    enum_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 枚举值id, 示例值："exGeIjow7zIqWMy+ONkFxA=="


@attr.s
class DeleteEmployeeTypeEnumResp(object):
    pass


def _gen_delete_employee_type_enum_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteEmployeeTypeEnumResp,
        scope="Contact",
        api="DeleteEmployeeTypeEnum",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/contact/v3/employee_type_enums/:enum_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_message_send import (
    SendRawMessageReq,
    SendRawMessageResp,
    _gen_send_raw_message_req,
)
from pylark.api_service_message_send_old import (
    SendRawMessageOldReq,
    SendRawMessageOldResp,
    _gen_send_raw_message_old_req,
)
from pylark.api_service_message_reply import (
    ReplyRawMessageReq,
    ReplyRawMessageResp,
    _gen_reply_raw_message_req,
)
from pylark.api_service_message_delete import (
    DeleteMessageReq,
    DeleteMessageResp,
    _gen_delete_message_req,
)
from pylark.api_service_message_update import (
    UpdateMessageReq,
    UpdateMessageResp,
    _gen_update_message_req,
)
from pylark.api_service_message_get_read_user_list import (
    GetMessageReadUserListReq,
    GetMessageReadUserListResp,
    _gen_get_message_read_user_list_req,
)
from pylark.api_service_message_list import (
    GetMessageListReq,
    GetMessageListResp,
    _gen_get_message_list_req,
)
from pylark.api_service_message_get_file import (
    GetMessageFileReq,
    GetMessageFileResp,
    _gen_get_message_file_req,
)
from pylark.api_service_message_get import (
    GetMessageReq,
    GetMessageResp,
    _gen_get_message_req,
)
from pylark.api_service_message_ephemeral_delete import (
    DeleteEphemeralMessageReq,
    DeleteEphemeralMessageResp,
    _gen_delete_ephemeral_message_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkMessageService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def send_raw_message(
        self, request: SendRawMessageReq, options: typing.List[str] = None
    ) -> typing.Tuple[SendRawMessageResp, Response]:
        return self.cli.raw_request(_gen_send_raw_message_req(request, options))

    def send_raw_message_old(
        self, request: SendRawMessageOldReq, options: typing.List[str] = None
    ) -> typing.Tuple[SendRawMessageOldResp, Response]:
        return self.cli.raw_request(_gen_send_raw_message_old_req(request, options))

    def reply_raw_message(
        self, request: ReplyRawMessageReq, options: typing.List[str] = None
    ) -> typing.Tuple[ReplyRawMessageResp, Response]:
        return self.cli.raw_request(_gen_reply_raw_message_req(request, options))

    def delete_message(
        self, request: DeleteMessageReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteMessageResp, Response]:
        return self.cli.raw_request(_gen_delete_message_req(request, options))

    def update_message(
        self, request: UpdateMessageReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateMessageResp, Response]:
        return self.cli.raw_request(_gen_update_message_req(request, options))

    def get_message_read_user_list(
        self, request: GetMessageReadUserListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMessageReadUserListResp, Response]:
        return self.cli.raw_request(
            _gen_get_message_read_user_list_req(request, options)
        )

    def get_message_list(
        self, request: GetMessageListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMessageListResp, Response]:
        return self.cli.raw_request(_gen_get_message_list_req(request, options))

    def get_message_file(
        self, request: GetMessageFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMessageFileResp, Response]:
        return self.cli.raw_request(_gen_get_message_file_req(request, options))

    def get_message(
        self, request: GetMessageReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetMessageResp, Response]:
        return self.cli.raw_request(_gen_get_message_req(request, options))

    def delete_ephemeral_message(
        self, request: DeleteEphemeralMessageReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteEphemeralMessageResp, Response]:
        return self.cli.raw_request(_gen_delete_ephemeral_message_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateAttendanceUserStatisticsSettingsReqViewItemChildItem(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题编号, 示例值："50101"
    value: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 开关字段,      , 可选值有: `0`：关闭, `1`：开启,非开关字段场景,  code = 51501  **可选值为1～6**


@attr.s
class UpdateAttendanceUserStatisticsSettingsReqViewItem(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 编号, 示例值："501"
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题名称, 示例值："基本信息"
    child_items: typing.List[
        UpdateAttendanceUserStatisticsSettingsReqViewItemChildItem
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 子标题


@attr.s
class UpdateAttendanceUserStatisticsSettingsReqView(object):
    view_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 视图 ID, 示例值："TmpnNU5EQXpPVGN3TmpVMU16Y3lPVEEwTXl0dGIyNTBhQT09"
    stats_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 统计类型, 可选值有: `daily`：日度统计, `month`：月度统计
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    items: typing.List[UpdateAttendanceUserStatisticsSettingsReqViewItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 一级标题


@attr.s
class UpdateAttendanceUserStatisticsSettingsReqEmployeeType(object):
    pass


@attr.s
class UpdateAttendanceUserStatisticsSettingsReq(object):
    employee_type: UpdateAttendanceUserStatisticsSettingsReqEmployeeType = attr.ib(
        factory=lambda: UpdateAttendanceUserStatisticsSettingsReqEmployeeType(),
        metadata={"req_type": "query"},
    )  # 用户 ID 类型, 可选值有: `employee_id`：用户员工 ID, `employee_no`：用户员工工号
    user_stats_view_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 用户视图 ID, 示例值："TmpZNU5qTTJORFF6T1RnNU5UTTNOakV6TWl0dGIyNTBhQT09"
    view: UpdateAttendanceUserStatisticsSettingsReqView = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 统计视图


@attr.s
class UpdateAttendanceUserStatisticsSettingsRespViewItemChildItem(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题编号
    value: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 是否开启,      , 可选值有: `0`：关闭, `1`：开启


@attr.s
class UpdateAttendanceUserStatisticsSettingsRespViewItem(object):
    code: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题编码
    title: str = attr.ib(default="", metadata={"req_type": "json"})  # 标题名称
    child_items: typing.List[
        UpdateAttendanceUserStatisticsSettingsRespViewItemChildItem
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 子标题


@attr.s
class UpdateAttendanceUserStatisticsSettingsRespView(object):
    view_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 统计视图 ID, 示例值："TmpnNU5EQXpPVGN3TmpVMU16Y3lPVEEwTXl0dGIyNTBhQT09"
    stats_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 统计类型, 可选值有: `daily`：日度统计, `month`：月度统计
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户 ID
    items: typing.List[UpdateAttendanceUserStatisticsSettingsRespViewItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 一级标题


@attr.s
class UpdateAttendanceUserStatisticsSettingsResp(object):
    view: UpdateAttendanceUserStatisticsSettingsRespView = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 用户视图


def _gen_update_attendance_user_statistics_settings_req(
    request, options
) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateAttendanceUserStatisticsSettingsResp,
        scope="Attendance",
        api="UpdateAttendanceUserStatisticsSettings",
        method="PUT",
        url="https://open.feishu.cn/open-apis/attendance/v1/user_stats_views/:user_stats_view_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_task_collaborator_create import (
    CreateTaskCollaboratorReq,
    CreateTaskCollaboratorResp,
    _gen_create_task_collaborator_req,
)
from pylark.api_service_task_collaborator_list import (
    GetTaskCollaboratorListReq,
    GetTaskCollaboratorListResp,
    _gen_get_task_collaborator_list_req,
)
from pylark.api_service_task_collaborator_delete import (
    DeleteTaskCollaboratorReq,
    DeleteTaskCollaboratorResp,
    _gen_delete_task_collaborator_req,
)
from pylark.api_service_task_follower_create import (
    CreateTaskFollowerReq,
    CreateTaskFollowerResp,
    _gen_create_task_follower_req,
)
from pylark.api_service_task_follower_list import (
    GetTaskFollowerListReq,
    GetTaskFollowerListResp,
    _gen_get_task_follower_list_req,
)
from pylark.api_service_task_follower_delete import (
    DeleteTaskFollowerReq,
    DeleteTaskFollowerResp,
    _gen_delete_task_follower_req,
)
from pylark.api_service_task_reminder_create import (
    CreateTaskReminderReq,
    CreateTaskReminderResp,
    _gen_create_task_reminder_req,
)
from pylark.api_service_task_reminder_list import (
    GetTaskReminderListReq,
    GetTaskReminderListResp,
    _gen_get_task_reminder_list_req,
)
from pylark.api_service_task_reminder_delete import (
    DeleteTaskReminderReq,
    DeleteTaskReminderResp,
    _gen_delete_task_reminder_req,
)
from pylark.api_service_task_task_create import (
    CreateTaskReq,
    CreateTaskResp,
    _gen_create_task_req,
)
from pylark.api_service_task_task import GetTaskReq, GetTaskResp, _gen_get_task_req
from pylark.api_service_task_task_delete import (
    DeleteTaskReq,
    DeleteTaskResp,
    _gen_delete_task_req,
)
from pylark.api_service_task_task_update import (
    UpdateTaskReq,
    UpdateTaskResp,
    _gen_update_task_req,
)
from pylark.api_service_task_task_complete import (
    CompleteTaskReq,
    CompleteTaskResp,
    _gen_complete_task_req,
)
from pylark.api_service_task_task_uncomplete import (
    UncompleteTaskReq,
    UncompleteTaskResp,
    _gen_uncomplete_task_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkTaskService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def create_task_collaborator(
        self, request: CreateTaskCollaboratorReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateTaskCollaboratorResp, Response]:
        return self.cli.raw_request(_gen_create_task_collaborator_req(request, options))

    def get_task_collaborator_list(
        self, request: GetTaskCollaboratorListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetTaskCollaboratorListResp, Response]:
        return self.cli.raw_request(
            _gen_get_task_collaborator_list_req(request, options)
        )

    def delete_task_collaborator(
        self, request: DeleteTaskCollaboratorReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteTaskCollaboratorResp, Response]:
        return self.cli.raw_request(_gen_delete_task_collaborator_req(request, options))

    def create_task_follower(
        self, request: CreateTaskFollowerReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateTaskFollowerResp, Response]:
        return self.cli.raw_request(_gen_create_task_follower_req(request, options))

    def get_task_follower_list(
        self, request: GetTaskFollowerListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetTaskFollowerListResp, Response]:
        return self.cli.raw_request(_gen_get_task_follower_list_req(request, options))

    def delete_task_follower(
        self, request: DeleteTaskFollowerReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteTaskFollowerResp, Response]:
        return self.cli.raw_request(_gen_delete_task_follower_req(request, options))

    def create_task_reminder(
        self, request: CreateTaskReminderReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateTaskReminderResp, Response]:
        return self.cli.raw_request(_gen_create_task_reminder_req(request, options))

    def get_task_reminder_list(
        self, request: GetTaskReminderListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetTaskReminderListResp, Response]:
        return self.cli.raw_request(_gen_get_task_reminder_list_req(request, options))

    def delete_task_reminder(
        self, request: DeleteTaskReminderReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteTaskReminderResp, Response]:
        return self.cli.raw_request(_gen_delete_task_reminder_req(request, options))

    def create_task(
        self, request: CreateTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateTaskResp, Response]:
        return self.cli.raw_request(_gen_create_task_req(request, options))

    def get_task(
        self, request: GetTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetTaskResp, Response]:
        return self.cli.raw_request(_gen_get_task_req(request, options))

    def delete_task(
        self, request: DeleteTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteTaskResp, Response]:
        return self.cli.raw_request(_gen_delete_task_req(request, options))

    def update_task(
        self, request: UpdateTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateTaskResp, Response]:
        return self.cli.raw_request(_gen_update_task_req(request, options))

    def complete_task(
        self, request: CompleteTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[CompleteTaskResp, Response]:
        return self.cli.raw_request(_gen_complete_task_req(request, options))

    def uncomplete_task(
        self, request: UncompleteTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[UncompleteTaskResp, Response]:
        return self.cli.raw_request(_gen_uncomplete_task_req(request, options))
